You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@geode.apache.org by ds...@apache.org on 2016/09/15 21:01:59 UTC

[42/76] [abbrv] [partial] incubator-geode git commit: GEODE-37 changed import to org.apache.geode

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/Cache.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/CacheCallback.java b/geode-core/src/main/java/org/apache/geode/cache/CacheCallback.java
index eae82ea..9b6964d 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/CacheCallback.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/CacheCallback.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 /**
  * User-defined objects that can be plugged into caching to receive callback

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/CacheClosedException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/CacheClosedException.java b/geode-core/src/main/java/org/apache/geode/cache/CacheClosedException.java
index f72dbe7..9c2be5d 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/CacheClosedException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/CacheClosedException.java
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
-import com.gemstone.gemfire.CancelException;
-import com.gemstone.gemfire.internal.cache.GemFireCacheImpl;
+import org.apache.geode.CancelException;
+import org.apache.geode.internal.cache.GemFireCacheImpl;
 
 /**
  * Indicates that the caching system has 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/CacheEvent.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/CacheEvent.java b/geode-core/src/main/java/org/apache/geode/cache/CacheEvent.java
index 8ee1a7f..44e4745 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/CacheEvent.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/CacheEvent.java
@@ -15,10 +15,10 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
-import com.gemstone.gemfire.distributed.DistributedMember;
-import com.gemstone.gemfire.internal.cache.EnumListenerEvent;
+import org.apache.geode.distributed.DistributedMember;
+import org.apache.geode.internal.cache.EnumListenerEvent;
 
 /**
  * A region- or entry-related event affecting the cache.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/CacheException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/CacheException.java b/geode-core/src/main/java/org/apache/geode/cache/CacheException.java
index e21b45b..9b631a1 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/CacheException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/CacheException.java
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
-import com.gemstone.gemfire.GemFireException;
+import org.apache.geode.GemFireException;
 
 
 /**

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/CacheExistsException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/CacheExistsException.java b/geode-core/src/main/java/org/apache/geode/cache/CacheExistsException.java
index 4292d03..610eb4c 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/CacheExistsException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/CacheExistsException.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 
 /** Thrown when attempting to create a {@link Cache} if one already exists.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/CacheFactory.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/CacheListener.java b/geode-core/src/main/java/org/apache/geode/cache/CacheListener.java
index 16966ff..db4bb3c 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/CacheListener.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/CacheListener.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 /**
  * <p>
@@ -23,7 +23,7 @@ package com.gemstone.gemfire.cache;
  * 
  * <p>
  * Instead of implementing this interface it is recommended that you extend the
- * {@link com.gemstone.gemfire.cache.util.CacheListenerAdapter} class.
+ * {@link org.apache.geode.cache.util.CacheListenerAdapter} class.
  * </p>
  * 
  * <h4>Avoiding the risk of deadlock</h4>

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/CacheLoader.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/CacheLoaderException.java b/geode-core/src/main/java/org/apache/geode/cache/CacheLoaderException.java
index 6261923..30e8ebe 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/CacheLoaderException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/CacheLoaderException.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 /** Thrown from the {@link CacheLoader#load} method indicating that an error
  * occurred when a CacheLoader was attempting to load a value. This
@@ -23,7 +23,7 @@ package com.gemstone.gemfire.cache;
  *
  *
  *
- * @see com.gemstone.gemfire.cache.Region#get(Object)
+ * @see org.apache.geode.cache.Region#get(Object)
  * @see CacheLoader#load
  * @since GemFire 3.0
  */

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/CacheRuntimeException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/CacheRuntimeException.java b/geode-core/src/main/java/org/apache/geode/cache/CacheRuntimeException.java
index 5f8c71e..9040596 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/CacheRuntimeException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/CacheRuntimeException.java
@@ -15,9 +15,9 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
-import com.gemstone.gemfire.GemFireException;
+import org.apache.geode.GemFireException;
 
 /** A generic runtime exception that indicates
  * a cache error has occurred. All the other runtime cache exceptions are the

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/CacheStatistics.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/CacheStatistics.java b/geode-core/src/main/java/org/apache/geode/cache/CacheStatistics.java
index a996ae8..5738c30 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/CacheStatistics.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/CacheStatistics.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 /**
  * Defines common statistics information

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/CacheTransactionManager.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/CacheWriter.java b/geode-core/src/main/java/org/apache/geode/cache/CacheWriter.java
index 574cc3b..318fed0 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/CacheWriter.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/CacheWriter.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 /** A user-defined object defined in the {@link RegionAttributes} that is
  * called synchronously before a region or entry in the cache is

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/CacheWriterException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/CacheXmlException.java b/geode-core/src/main/java/org/apache/geode/cache/CacheXmlException.java
index 69f2430..c6db5c7 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/CacheXmlException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/CacheXmlException.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 /**
  * Thrown when a problem is encountered while parsing a <A

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/ClientSession.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/CommitConflictException.java b/geode-core/src/main/java/org/apache/geode/cache/CommitConflictException.java
index 7e271e5..be3575f 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/CommitConflictException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/CommitConflictException.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 /** Thrown when a commit fails due to a write conflict.
  *

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/CommitDistributionException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/CommitDistributionException.java b/geode-core/src/main/java/org/apache/geode/cache/CommitDistributionException.java
index 9649bac..eea0b56 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/CommitDistributionException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/CommitDistributionException.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 import java.util.*;
 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/CommitIncompleteException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/CommitIncompleteException.java b/geode-core/src/main/java/org/apache/geode/cache/CommitIncompleteException.java
index a708f42..26544e8 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/CommitIncompleteException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/CommitIncompleteException.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 /**
  * Thrown when a commit fails to complete due to errors

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/CustomExpiry.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/CustomExpiry.java b/geode-core/src/main/java/org/apache/geode/cache/CustomExpiry.java
index 94b73c0..25f89eb 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/CustomExpiry.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/CustomExpiry.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 /**
  * This is the contract that a <code>custom-expiry</code> element must honor.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/DataPolicy.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/DataPolicy.java b/geode-core/src/main/java/org/apache/geode/cache/DataPolicy.java
index e9bde30..8d1c2e0 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/DataPolicy.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/DataPolicy.java
@@ -16,8 +16,8 @@
  */
 
 
-package com.gemstone.gemfire.cache;
-import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
+package org.apache.geode.cache;
+import org.apache.geode.internal.i18n.LocalizedStrings;
 
 import java.io.*;
 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/Declarable.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/Declarable.java b/geode-core/src/main/java/org/apache/geode/cache/Declarable.java
index 57d0dd4..113d098 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/Declarable.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/Declarable.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 import java.util.Properties;
 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/DiskAccessException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/DiskAccessException.java b/geode-core/src/main/java/org/apache/geode/cache/DiskAccessException.java
index e8787da..9571f93 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/DiskAccessException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/DiskAccessException.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 import java.io.IOException;
 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/DiskStore.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/DiskStore.java b/geode-core/src/main/java/org/apache/geode/cache/DiskStore.java
index 2ccb84c..f425b90 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/DiskStore.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/DiskStore.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 import java.io.File;
 import java.util.UUID;

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/DiskStoreFactory.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/DiskStoreFactory.java b/geode-core/src/main/java/org/apache/geode/cache/DiskStoreFactory.java
index 620c79f..3956682 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/DiskStoreFactory.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/DiskStoreFactory.java
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
-import com.gemstone.gemfire.distributed.internal.DistributionConfig;
+import org.apache.geode.distributed.internal.DistributionConfig;
 
 import java.io.File;
 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/DiskWriteAttributes.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/DiskWriteAttributes.java b/geode-core/src/main/java/org/apache/geode/cache/DiskWriteAttributes.java
index 426b402..bc42112 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/DiskWriteAttributes.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/DiskWriteAttributes.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 /**
  * Immutable parameter object for describing how {@linkplain

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/DiskWriteAttributesFactory.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/DiskWriteAttributesFactory.java b/geode-core/src/main/java/org/apache/geode/cache/DiskWriteAttributesFactory.java
index 4060ffb..f56fc8d 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/DiskWriteAttributesFactory.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/DiskWriteAttributesFactory.java
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
-import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
+import org.apache.geode.internal.i18n.LocalizedStrings;
 import java.util.Properties;
 
-import com.gemstone.gemfire.internal.cache.DiskWriteAttributesImpl;
-import com.gemstone.gemfire.internal.cache.xmlcache.CacheXml;
+import org.apache.geode.internal.cache.DiskWriteAttributesImpl;
+import org.apache.geode.internal.cache.xmlcache.CacheXml;
 
 /**
  * Factory for getting DiskWriteAttribute objects

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/DuplicatePrimaryPartitionException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/DuplicatePrimaryPartitionException.java b/geode-core/src/main/java/org/apache/geode/cache/DuplicatePrimaryPartitionException.java
index f5ecd76..74a1753 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/DuplicatePrimaryPartitionException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/DuplicatePrimaryPartitionException.java
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
-import com.gemstone.gemfire.GemFireException;
+import org.apache.geode.GemFireException;
 
 /**
  * This exception is thrown when two nodes are defined with same primary

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/DynamicRegionFactory.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/DynamicRegionFactory.java b/geode-core/src/main/java/org/apache/geode/cache/DynamicRegionFactory.java
index 1f449cd..3cfa73b 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/DynamicRegionFactory.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/DynamicRegionFactory.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 import java.io.File;
 import java.io.IOException;
@@ -26,29 +26,29 @@ import java.util.List;
 import java.util.Set;
 import java.util.TreeMap;
 
-import com.gemstone.gemfire.InternalGemFireError;
-import com.gemstone.gemfire.SystemFailure;
-import com.gemstone.gemfire.cache.client.Pool;
-import com.gemstone.gemfire.cache.client.PoolManager;
-import com.gemstone.gemfire.cache.client.internal.ServerRegionProxy;
-import com.gemstone.gemfire.cache.wan.GatewaySender;
-import com.gemstone.gemfire.distributed.DistributedMember;
-import com.gemstone.gemfire.distributed.internal.InternalDistributedSystem;
-import com.gemstone.gemfire.internal.Assert;
-import com.gemstone.gemfire.internal.cache.DistributedRegion;
-import com.gemstone.gemfire.internal.cache.DynamicRegionAttributes;
-import com.gemstone.gemfire.internal.cache.DynamicRegionFactoryImpl;
-import com.gemstone.gemfire.internal.cache.EntryEventImpl;
-import com.gemstone.gemfire.internal.cache.EnumListenerEvent;
-import com.gemstone.gemfire.internal.cache.EvictionAttributesImpl;
-import com.gemstone.gemfire.internal.cache.GemFireCacheImpl;
-import com.gemstone.gemfire.internal.cache.InitialImageOperation;
-import com.gemstone.gemfire.internal.cache.InternalRegionArguments;
-import com.gemstone.gemfire.internal.cache.LocalRegion;
-import com.gemstone.gemfire.internal.cache.RegionEntry;
-import com.gemstone.gemfire.internal.cache.RegionEventImpl;
-import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
-import com.gemstone.gemfire.security.GemFireSecurityException;
+import org.apache.geode.InternalGemFireError;
+import org.apache.geode.SystemFailure;
+import org.apache.geode.cache.client.Pool;
+import org.apache.geode.cache.client.PoolManager;
+import org.apache.geode.cache.client.internal.ServerRegionProxy;
+import org.apache.geode.cache.wan.GatewaySender;
+import org.apache.geode.distributed.DistributedMember;
+import org.apache.geode.distributed.internal.InternalDistributedSystem;
+import org.apache.geode.internal.Assert;
+import org.apache.geode.internal.cache.DistributedRegion;
+import org.apache.geode.internal.cache.DynamicRegionAttributes;
+import org.apache.geode.internal.cache.DynamicRegionFactoryImpl;
+import org.apache.geode.internal.cache.EntryEventImpl;
+import org.apache.geode.internal.cache.EnumListenerEvent;
+import org.apache.geode.internal.cache.EvictionAttributesImpl;
+import org.apache.geode.internal.cache.GemFireCacheImpl;
+import org.apache.geode.internal.cache.InitialImageOperation;
+import org.apache.geode.internal.cache.InternalRegionArguments;
+import org.apache.geode.internal.cache.LocalRegion;
+import org.apache.geode.internal.cache.RegionEntry;
+import org.apache.geode.internal.cache.RegionEventImpl;
+import org.apache.geode.internal.i18n.LocalizedStrings;
+import org.apache.geode.security.GemFireSecurityException;
 
 
 /**

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/DynamicRegionListener.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/DynamicRegionListener.java b/geode-core/src/main/java/org/apache/geode/cache/DynamicRegionListener.java
index e679cb7..b8a47de 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/DynamicRegionListener.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/DynamicRegionListener.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 /**
  * <code>DynamicRegionListener</code> is an interface that can be

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/EntryDestroyedException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/EntryDestroyedException.java b/geode-core/src/main/java/org/apache/geode/cache/EntryDestroyedException.java
index 6ae0227..2958ad0 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/EntryDestroyedException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/EntryDestroyedException.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 /**
  * Indicates that a method was invoked on an entry that has been destroyed.
  *

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/EntryEvent.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/EntryEvent.java b/geode-core/src/main/java/org/apache/geode/cache/EntryEvent.java
index 84eec6e..8dda363 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/EntryEvent.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/EntryEvent.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 //import java.io.*;
 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/EntryExistsException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/EntryExistsException.java b/geode-core/src/main/java/org/apache/geode/cache/EntryExistsException.java
index 14e4146..15f915f 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/EntryExistsException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/EntryExistsException.java
@@ -15,12 +15,12 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 /** Thrown when attempting to create a <code>Region.Entry</code> that already
  * exists in the <code>Region</code>.
  *
- * @see com.gemstone.gemfire.cache.Region#create(Object, Object)
+ * @see org.apache.geode.cache.Region#create(Object, Object)
  * @see Region.Entry
  * @since GemFire 3.0
  */

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/EntryNotFoundException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/EntryNotFoundInRegion.java b/geode-core/src/main/java/org/apache/geode/cache/EntryNotFoundInRegion.java
index 2b848ef..17105b1 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/EntryNotFoundInRegion.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/EntryNotFoundInRegion.java
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
-import com.gemstone.gemfire.GemFireException;
-import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
-import com.gemstone.gemfire.InternalGemFireError;
+import org.apache.geode.GemFireException;
+import org.apache.geode.internal.i18n.LocalizedStrings;
+import org.apache.geode.InternalGemFireError;
 
 /**
  * @deprecated this class is no longer in use

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/EntryOperation.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/EntryOperation.java b/geode-core/src/main/java/org/apache/geode/cache/EntryOperation.java
index 2e44ef8..90b0485 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/EntryOperation.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/EntryOperation.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 /**
  * Gemfire Context passed to <code>PartitionResolver</code> to compute the

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/EvictionAction.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/EvictionAlgorithm.java b/geode-core/src/main/java/org/apache/geode/cache/EvictionAlgorithm.java
index 0ec010e..e9be783 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/EvictionAlgorithm.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/EvictionAlgorithm.java
@@ -14,15 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 import javax.print.attribute.EnumSyntax;
 
-/** The algorithm used to determine when to perform an {@link com.gemstone.gemfire.cache.EvictionAction}
+/** The algorithm used to determine when to perform an {@link org.apache.geode.cache.EvictionAction}
  * 
  * @since GemFire 5.0
- * @see com.gemstone.gemfire.cache.EvictionAction
- * @see com.gemstone.gemfire.internal.cache.EvictionAttributesImpl
+ * @see org.apache.geode.cache.EvictionAction
+ * @see org.apache.geode.internal.cache.EvictionAttributesImpl
  */
 public final class EvictionAlgorithm extends EnumSyntax
 {

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/EvictionAttributes.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/ExpirationAction.java b/geode-core/src/main/java/org/apache/geode/cache/ExpirationAction.java
index dace6c0..c958b34 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/ExpirationAction.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/ExpirationAction.java
@@ -16,7 +16,7 @@
  */
 
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 import java.io.*;
 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/ExpirationAttributes.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/ExpirationAttributes.java b/geode-core/src/main/java/org/apache/geode/cache/ExpirationAttributes.java
index ad854e7..22d507e 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/ExpirationAttributes.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/ExpirationAttributes.java
@@ -15,15 +15,15 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 import java.io.DataInput;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import com.gemstone.gemfire.DataSerializable;
-import com.gemstone.gemfire.DataSerializer;
-import com.gemstone.gemfire.internal.InternalDataSerializer;
+import org.apache.geode.DataSerializable;
+import org.apache.geode.DataSerializer;
+import org.apache.geode.internal.InternalDataSerializer;
 
 /** Immutable parameter object for accessing and setting the attributes associated with 
  * <code>timeToLive</code> and <code>idleTimeout</code>. If the expiration

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/FailedSynchronizationException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/FailedSynchronizationException.java b/geode-core/src/main/java/org/apache/geode/cache/FailedSynchronizationException.java
index 7c44307..9cff54f 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/FailedSynchronizationException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/FailedSynchronizationException.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 import javax.transaction.Status;
 import javax.transaction.Transaction;

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/FixedPartitionAttributes.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/FixedPartitionAttributes.java b/geode-core/src/main/java/org/apache/geode/cache/FixedPartitionAttributes.java
index cb648db..4ada70d 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/FixedPartitionAttributes.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/FixedPartitionAttributes.java
@@ -14,22 +14,22 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
-import com.gemstone.gemfire.internal.cache.FixedPartitionAttributesImpl;
+import org.apache.geode.internal.cache.FixedPartitionAttributesImpl;
 
 /**
  * Composite date type used to distribute the attributes for a fixed partition.
  * </p>
  * 
- * {@link com.gemstone.gemfire.cache.PartitionAttributes#getFixedPartitionAttributes()}
+ * {@link org.apache.geode.cache.PartitionAttributes#getFixedPartitionAttributes()}
  * returns all fixed partitions in Partitioned Region attributes. </p>
- * {@link com.gemstone.gemfire.cache.PartitionAttributesFactory#addFixedPartitionAttributes(FixedPartitionAttributes)}
+ * {@link org.apache.geode.cache.PartitionAttributesFactory#addFixedPartitionAttributes(FixedPartitionAttributes)}
  * configures <code>FixedPartitionAttributes</Code> in
  * <code>PartitionedRegionAttributes</code> </p>
  * 
- * @see com.gemstone.gemfire.cache.PartitionAttributes
- * @see com.gemstone.gemfire.cache.PartitionAttributesFactory
+ * @see org.apache.geode.cache.PartitionAttributes
+ * @see org.apache.geode.cache.PartitionAttributesFactory
  * 
  * @since GemFire 6.6
  */

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/FixedPartitionResolver.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/GatewayConfigurationException.java b/geode-core/src/main/java/org/apache/geode/cache/GatewayConfigurationException.java
index 954d6c8..d7760a8 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/GatewayConfigurationException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/GatewayConfigurationException.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 
 /**

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/GatewayException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/GatewayException.java b/geode-core/src/main/java/org/apache/geode/cache/GatewayException.java
index f8a9d0e..e47c51d 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/GatewayException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/GatewayException.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 /**
  * An exception thrown by a <code>Gateway</code>.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/GemFireCache.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/GemFireCache.java b/geode-core/src/main/java/org/apache/geode/cache/GemFireCache.java
index b1ac678..05daa38 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/GemFireCache.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/GemFireCache.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 import java.io.InputStream;
 import java.util.Map;
@@ -23,13 +23,13 @@ import java.util.Properties;
 
 import javax.naming.Context;
 
-import com.gemstone.gemfire.LogWriter;
-import com.gemstone.gemfire.cache.client.ClientCache;
-import com.gemstone.gemfire.cache.client.ClientCacheFactory;
-import com.gemstone.gemfire.cache.control.ResourceManager;
-import com.gemstone.gemfire.cache.wan.GatewaySenderFactory;
-import com.gemstone.gemfire.distributed.DistributedSystem;
-import com.gemstone.gemfire.pdx.PdxSerializer;
+import org.apache.geode.LogWriter;
+import org.apache.geode.cache.client.ClientCache;
+import org.apache.geode.cache.client.ClientCacheFactory;
+import org.apache.geode.cache.control.ResourceManager;
+import org.apache.geode.cache.wan.GatewaySenderFactory;
+import org.apache.geode.distributed.DistributedSystem;
+import org.apache.geode.pdx.PdxSerializer;
 
 /**
  * GemFireCache represents the singleton cache that must be created
@@ -185,8 +185,8 @@ public interface GemFireCache extends RegionService {
   
   /**
    * Returns whether { @link PdxInstance} is preferred for PDX types instead of Java object.
-   * @see com.gemstone.gemfire.cache.CacheFactory#setPdxReadSerialized(boolean)
-   * @see com.gemstone.gemfire.cache.client.ClientCacheFactory#setPdxReadSerialized(boolean)
+   * @see org.apache.geode.cache.CacheFactory#setPdxReadSerialized(boolean)
+   * @see org.apache.geode.cache.client.ClientCacheFactory#setPdxReadSerialized(boolean)
    * 
    * @since GemFire 6.6
    */

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/IncompatibleVersionException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/IncompatibleVersionException.java b/geode-core/src/main/java/org/apache/geode/cache/IncompatibleVersionException.java
index 7f76bd9..96afd80 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/IncompatibleVersionException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/IncompatibleVersionException.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 /**
  * An <code>IncompatibleVersionException</code> that the client version

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/InterestPolicy.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/InterestPolicy.java b/geode-core/src/main/java/org/apache/geode/cache/InterestPolicy.java
index 7200bc6..185c84c 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/InterestPolicy.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/InterestPolicy.java
@@ -16,7 +16,7 @@
  */
 
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 import java.io.*;
 
 /**

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/InterestRegistrationEvent.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/InterestRegistrationEvent.java b/geode-core/src/main/java/org/apache/geode/cache/InterestRegistrationEvent.java
index b2f9b0a..74ca188 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/InterestRegistrationEvent.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/InterestRegistrationEvent.java
@@ -15,11 +15,11 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 import java.util.Set;
 
-import com.gemstone.gemfire.internal.cache.tier.InterestType;
+import org.apache.geode.internal.cache.tier.InterestType;
 
 /**
  * Interface <code>InterestRegistrationEvent</code> encapsulated interest

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/InterestRegistrationListener.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/InterestResultPolicy.java b/geode-core/src/main/java/org/apache/geode/cache/InterestResultPolicy.java
index 7dee649..76ed438 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/InterestResultPolicy.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/InterestResultPolicy.java
@@ -16,9 +16,9 @@
  */
 
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
-import com.gemstone.gemfire.internal.cache.tier.sockets.InterestResultPolicyImpl;
+import org.apache.geode.internal.cache.tier.sockets.InterestResultPolicyImpl;
 import java.io.ObjectStreamException;
 import java.io.Serializable;
 
@@ -28,8 +28,8 @@ import java.io.Serializable;
  * can be the keys and current values, just the keys or nothing.
  *
  *
- * @see com.gemstone.gemfire.cache.Region#registerInterest(Object)
- * @see com.gemstone.gemfire.cache.Region#registerInterestRegex(String)
+ * @see org.apache.geode.cache.Region#registerInterest(Object)
+ * @see org.apache.geode.cache.Region#registerInterestRegex(String)
  *
  * @since GemFire 4.2.3
  */

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/LoaderHelper.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/LoaderHelper.java b/geode-core/src/main/java/org/apache/geode/cache/LoaderHelper.java
index 86aa329..75d04fe 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/LoaderHelper.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/LoaderHelper.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 /** Provides a set of APIs to help the
  * implementation of the <code>CacheLoader</code> load method. An instance of <code>LoaderHelper</code>
@@ -50,7 +50,7 @@ public interface LoaderHelper<K,V>
    *         getting a response from another cache
    * @throws CacheLoaderException
    *         If <code>netSearch</code> is attempted on a {@linkplain
-   *         com.gemstone.gemfire.cache.Scope#LOCAL local} region. 
+   *         org.apache.geode.cache.Scope#LOCAL local} region. 
    */
   public V netSearch(boolean doNetLoad)
     throws CacheLoaderException, TimeoutException;

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/LossAction.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/LossAction.java b/geode-core/src/main/java/org/apache/geode/cache/LossAction.java
index 7c428a1..7258da4 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/LossAction.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/LossAction.java
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
-import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
+import org.apache.geode.internal.i18n.LocalizedStrings;
 
 import java.io.*;
 import java.util.*;
@@ -26,7 +26,7 @@ import java.util.*;
  * roles are lost. A role is lost when it is are offline and no longer
  * present in the system membership.
  * The <code>LossAction</code> is specified when configuring a region's
- * {@link com.gemstone.gemfire.cache.MembershipAttributes}.
+ * {@link org.apache.geode.cache.MembershipAttributes}.
  * 
  * @deprecated this feature is scheduled to be removed
  */

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/LowMemoryException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/LowMemoryException.java b/geode-core/src/main/java/org/apache/geode/cache/LowMemoryException.java
index aee073a..fe4849a 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/LowMemoryException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/LowMemoryException.java
@@ -15,14 +15,14 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 import java.util.Collections;
 import java.util.HashSet;
 import java.util.Set;
 
-import com.gemstone.gemfire.cache.control.ResourceManager;
-import com.gemstone.gemfire.distributed.DistributedMember;
+import org.apache.geode.cache.control.ResourceManager;
+import org.apache.geode.distributed.DistributedMember;
 
 /**
  * Indicates a low memory condition either on the local or a remote {@link Cache}.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/MembershipAttributes.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/MirrorType.java b/geode-core/src/main/java/org/apache/geode/cache/MirrorType.java
index 76b34a8..6b3d602 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/MirrorType.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/MirrorType.java
@@ -16,7 +16,7 @@
  */
 
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 import java.io.*;
 
 /**

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/NoQueueServersAvailableException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/NoQueueServersAvailableException.java b/geode-core/src/main/java/org/apache/geode/cache/NoQueueServersAvailableException.java
index 0217e91..2361c8d 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/NoQueueServersAvailableException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/NoQueueServersAvailableException.java
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
-import com.gemstone.gemfire.cache.client.ServerConnectivityException;
+import org.apache.geode.cache.client.ServerConnectivityException;
 
 /**
  * Indicates that this client cannot contact any queue servers and

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/NoSubscriptionServersAvailableException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/NoSubscriptionServersAvailableException.java b/geode-core/src/main/java/org/apache/geode/cache/NoSubscriptionServersAvailableException.java
index 9c72e44..53ca591 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/NoSubscriptionServersAvailableException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/NoSubscriptionServersAvailableException.java
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
-import com.gemstone.gemfire.cache.client.ServerConnectivityException;
+import org.apache.geode.cache.client.ServerConnectivityException;
 
 /**
  * Indicates that this client cannot contact any servers and

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/Operation.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/Operation.java b/geode-core/src/main/java/org/apache/geode/cache/Operation.java
index 2634416..283069a 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/Operation.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/Operation.java
@@ -16,10 +16,10 @@
  */
 
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 import java.io.*;
-import com.gemstone.gemfire.internal.cache.OpType;
-import com.gemstone.gemfire.cache.execute.FunctionService;
+import org.apache.geode.internal.cache.OpType;
+import org.apache.geode.cache.execute.FunctionService;
 
 /**
  * Enumerated type for an event operation.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/OperationAbortedException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/OperationAbortedException.java b/geode-core/src/main/java/org/apache/geode/cache/OperationAbortedException.java
index f596f7e..340d184 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/OperationAbortedException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/OperationAbortedException.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 /** Indicates that the operation that
  * would have otherwise affected the cache has been aborted.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/PartitionAttributes.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/PartitionResolver.java b/geode-core/src/main/java/org/apache/geode/cache/PartitionResolver.java
index 253a108..a286e37 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/PartitionResolver.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/PartitionResolver.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 /**
  * Implementers of interface <code>PartitionResolver</code> enable custom

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/PartitionedRegionDistributionException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/PartitionedRegionDistributionException.java b/geode-core/src/main/java/org/apache/geode/cache/PartitionedRegionDistributionException.java
index 9a3ed77..2fc6e1c 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/PartitionedRegionDistributionException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/PartitionedRegionDistributionException.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 /**
  * Indicates a failure to perform a distributed operation on a Partitioned Region 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/PartitionedRegionStorageException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/PartitionedRegionStorageException.java b/geode-core/src/main/java/org/apache/geode/cache/PartitionedRegionStorageException.java
index 7334f89..cdb0d18 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/PartitionedRegionStorageException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/PartitionedRegionStorageException.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 /**
  * 
@@ -65,7 +65,7 @@ package com.gemstone.gemfire.cache;
  * </p>
  * 
  * 
- * @see com.gemstone.gemfire.cache.PartitionAttributesFactory
+ * @see org.apache.geode.cache.PartitionAttributesFactory
  * @since GemFire 5.0
  */
 public class PartitionedRegionStorageException extends CacheRuntimeException  {
diff --git a/geode-core/src/main/java/org/apache/geode/cache/Cache.java b/geode-core/src/main/java/org/apache/geode/cache/Cache.java
index a17fdd2..773654b 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/Cache.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/Cache.java
@@ -15,26 +15,26 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 import java.util.List;
 import java.util.Set;
 import java.util.concurrent.TimeUnit;
 
-import com.gemstone.gemfire.cache.asyncqueue.AsyncEventQueue;
-import com.gemstone.gemfire.cache.asyncqueue.AsyncEventQueueFactory;
-import com.gemstone.gemfire.cache.client.ClientCache;
-import com.gemstone.gemfire.cache.client.Pool;
-import com.gemstone.gemfire.cache.server.CacheServer;
-import com.gemstone.gemfire.cache.snapshot.CacheSnapshotService;
-import com.gemstone.gemfire.cache.util.GatewayConflictResolver;
-import com.gemstone.gemfire.cache.wan.GatewayReceiver;
-import com.gemstone.gemfire.cache.wan.GatewayReceiverFactory;
-import com.gemstone.gemfire.cache.wan.GatewaySender;
-import com.gemstone.gemfire.cache.wan.GatewaySenderFactory;
-import com.gemstone.gemfire.distributed.DistributedMember;
-import com.gemstone.gemfire.distributed.DistributedSystem;
-import com.gemstone.gemfire.i18n.LogWriterI18n;
+import org.apache.geode.cache.asyncqueue.AsyncEventQueue;
+import org.apache.geode.cache.asyncqueue.AsyncEventQueueFactory;
+import org.apache.geode.cache.client.ClientCache;
+import org.apache.geode.cache.client.Pool;
+import org.apache.geode.cache.server.CacheServer;
+import org.apache.geode.cache.snapshot.CacheSnapshotService;
+import org.apache.geode.cache.util.GatewayConflictResolver;
+import org.apache.geode.cache.wan.GatewayReceiver;
+import org.apache.geode.cache.wan.GatewayReceiverFactory;
+import org.apache.geode.cache.wan.GatewaySender;
+import org.apache.geode.cache.wan.GatewaySenderFactory;
+import org.apache.geode.distributed.DistributedMember;
+import org.apache.geode.distributed.DistributedSystem;
+import org.apache.geode.i18n.LogWriterI18n;
 
 
 /** 
@@ -84,7 +84,7 @@ public interface Cache extends GemFireCache {
    * @return the region object
    * @throws RegionExistsException if a region is already in
    * this cache
    * @throws com.gemstone.gemfire.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
    * @throws TimeoutException if timed out getting distributed lock for Scope.GLOBAL
    * @throws CacheClosedException if the cache is closed
    * @throws IllegalStateException If the supplied RegionAttributes violate the
@@ -103,7 +103,7 @@ public interface Cache extends GemFireCache {
    * @param aRegionAttributes the attributes of the root region
    * @return the region object
    * @throws RegionExistsException if a region is already in this cache
    * @throws com.gemstone.gemfire.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
    * @throws TimeoutException if timed out getting distributed lock for Scope.GLOBAL
    * @throws CacheClosedException if the cache is closed
    * @throws IllegalStateException If the supplied RegionAttributes violate the
@@ -224,7 +224,7 @@ public interface Cache extends GemFireCache {
   
   /**
    * Gets the number of seconds a cache
-   * {@link com.gemstone.gemfire.cache.Region#get(Object) get} operation
+   * {@link org.apache.geode.cache.Region#get(Object) get} operation
    * can spend searching for a value before it times out.
    * The search includes any time spent loading the object.
    * When the search times out it causes the get to fail by throwing
@@ -245,9 +245,9 @@ public interface Cache extends GemFireCache {
    * Creates a new cache server, with the default configuration,
    * that will allow clients to access this cache.
    * <p>For the default configuration see the constants in
-   * {@link com.gemstone.gemfire.cache.server.CacheServer}.
+   * {@link org.apache.geode.cache.server.CacheServer}.
    * 
-   * @see com.gemstone.gemfire.cache.server.CacheServer
+   * @see org.apache.geode.cache.server.CacheServer
    *
    * @since GemFire 5.7
    */
@@ -286,7 +286,7 @@ public interface Cache extends GemFireCache {
    * Sets whether or not this <code>Cache</code> resides in a
    * long-running "cache server" VM.  A cache server may be an
    * application VM or may be a stand-along VM launched using {@linkplain
-   * com.gemstone.gemfire.admin.AdminDistributedSystem#addCacheServer
+   * org.apache.geode.admin.AdminDistributedSystem#addCacheServer
    * administration API} or the <code>cacheserver</code> command line
    * utility.
    *

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/CacheCallback.java
----------------------------------------------------------------------
@@ -84,7 +84,7 @@ public interface Cache extends GemFireCache {
    * @throws RegionExistsException if a region is already in
    * this cache
-   * @throws com.gemstone.gemfire.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
+   * @throws org.apache.geode.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
    * @throws TimeoutException if timed out getting distributed lock for Scope.GLOBAL
    * @throws CacheClosedException if the cache is closed
@@ -103,7 +103,7 @@ public interface Cache extends GemFireCache {
    * @return the region object
    * @throws RegionExistsException if a region is already in this cache
-   * @throws com.gemstone.gemfire.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
+   * @throws org.apache.geode.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
    * @throws TimeoutException if timed out getting distributed lock for Scope.GLOBAL
    * @throws CacheClosedException if the cache is closed
diff --git a/geode-core/src/main/java/org/apache/geode/cache/CacheFactory.java b/geode-core/src/main/java/org/apache/geode/cache/CacheFactory.java
index 991b27f..6d3fd4b 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/CacheFactory.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/CacheFactory.java
@@ -15,25 +15,25 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 import java.util.Properties;
 
-import com.gemstone.gemfire.distributed.ConfigurationProperties;
-import com.gemstone.gemfire.distributed.DistributedSystem;
-import com.gemstone.gemfire.distributed.internal.InternalDistributedSystem;
-import com.gemstone.gemfire.internal.GemFireVersion;
-import com.gemstone.gemfire.internal.cache.CacheConfig;
-import com.gemstone.gemfire.internal.cache.GemFireCacheImpl;
-import com.gemstone.gemfire.internal.cache.LocalRegion;
-import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
-import com.gemstone.gemfire.internal.jndi.JNDIInvoker;
-import com.gemstone.gemfire.pdx.PdxInstance;
-import com.gemstone.gemfire.pdx.PdxSerializer;
+import org.apache.geode.distributed.ConfigurationProperties;
+import org.apache.geode.distributed.DistributedSystem;
+import org.apache.geode.distributed.internal.InternalDistributedSystem;
+import org.apache.geode.internal.GemFireVersion;
+import org.apache.geode.internal.cache.CacheConfig;
+import org.apache.geode.internal.cache.GemFireCacheImpl;
+import org.apache.geode.internal.cache.LocalRegion;
+import org.apache.geode.internal.i18n.LocalizedStrings;
+import org.apache.geode.internal.jndi.JNDIInvoker;
+import org.apache.geode.pdx.PdxInstance;
+import org.apache.geode.pdx.PdxSerializer;
 
 
 /**
  * Factory class used to create the singleton {@link Cache cache} and connect to the GemFire singleton {@link DistributedSystem distributed system}. If the application wants to connect to GemFire as a client it should use {@link com.gemstone.gemfire.cache.client.ClientCacheFactory} instead.
 <p> Once the factory has been configured using its {@link #set(String, String)} method you produce a {@link Cache} by calling the {@link #create()} method.
  * <p>
  * To get the existing unclosed singleton cache instance call {@link #getAnyInstance}.
@@ -323,7 +323,7 @@ public class CacheFactory {
    *  @param readSerialized true to prefer PdxInstance
    *  @return this CacheFactory 
    *  @since GemFire 6.6
-   *  @see com.gemstone.gemfire.pdx.PdxInstance 
+   *  @see org.apache.geode.pdx.PdxInstance 
    */
   public  CacheFactory setPdxReadSerialized(boolean readSerialized) {
     this.cacheConfig.setPdxReadSerialized(readSerialized);

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/CacheListener.java
----------------------------------------------------------------------
@@ -15,25 +15,25 @@
 
 /**
- * Factory class used to create the singleton {@link Cache cache} and connect to the GemFire singleton {@link DistributedSystem distributed system}. If the application wants to connect to GemFire as a client it should use {@link com.gemstone.gemfire.cache.client.ClientCacheFactory} instead.
+ * Factory class used to create the singleton {@link Cache cache} and connect to the GemFire singleton {@link DistributedSystem distributed system}. If the application wants to connect to GemFire as a client it should use {@link org.apache.geode.cache.client.ClientCacheFactory} instead.
 <p> Once the factory has been configured using its {@link #set(String, String)} method you produce a {@link Cache} by calling the {@link #create()} method.
  * <p>
diff --git a/geode-core/src/main/java/org/apache/geode/cache/CacheLoader.java b/geode-core/src/main/java/org/apache/geode/cache/CacheLoader.java
index 2def607..7bb30c7 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/CacheLoader.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/CacheLoader.java
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 /**
  * Allows data from outside of the VM to be placed into a region.  
  * When {@link com.gemstone.gemfire.cache.Region#get(Object)} is called for a region
  * entry that has a <code>null</code> value, the 
  * {@link CacheLoader#load load} method of the
  * region's cache loader is invoked.  The <code>load</code> method

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/CacheLoaderException.java
----------------------------------------------------------------------
@@ -14,11 +14,11 @@
 /**
  * Allows data from outside of the VM to be placed into a region.  
- * When {@link com.gemstone.gemfire.cache.Region#get(Object)} is called for a region
+ * When {@link org.apache.geode.cache.Region#get(Object)} is called for a region
  * entry that has a <code>null</code> value, the 
  * {@link CacheLoader#load load} method of the
diff --git a/geode-core/src/main/java/org/apache/geode/cache/CacheTransactionManager.java b/geode-core/src/main/java/org/apache/geode/cache/CacheTransactionManager.java
index ef9a93e..90651f3 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/CacheTransactionManager.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/CacheTransactionManager.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 import java.util.concurrent.TimeUnit;
 
@@ -66,7 +66,7 @@ import java.util.concurrent.TimeUnit;
  * 
  *  <p>To aid in creating copies, the "copy on read"
  *  <code>Cache</code> attribute and the {@link
  *  com.gemstone.gemfire.CopyHelper#copy} method are provided.
  *  The following is a Read Committed safe example using the
  *  <code>CopyHelper.copy</code> method.
  * 
@@ -87,7 +87,7 @@ import java.util.concurrent.TimeUnit;
  * (see {@link AttributesFactory} for Scope).  For both scopes, a
  * consistent configuration (per VM) is enforced.
  * 
  * <p>Global Regions, client Regions (see com.gemstone.gemfire.cache.client package)
  * and persistent Regions (see {@link DiskWriteAttributes}) do not
  * support transactions.
  * 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/CacheWriter.java
----------------------------------------------------------------------
@@ -66,7 +66,7 @@ import java.util.concurrent.TimeUnit;
  *  <p>To aid in creating copies, the "copy on read"
  *  <code>Cache</code> attribute and the {@link
- *  com.gemstone.gemfire.CopyHelper#copy} method are provided.
+ *  org.apache.geode.CopyHelper#copy} method are provided.
  *  The following is a Read Committed safe example using the
  *  <code>CopyHelper.copy</code> method.
@@ -87,7 +87,7 @@ import java.util.concurrent.TimeUnit;
  * consistent configuration (per VM) is enforced.
  * 
- * <p>Global Regions, client Regions (see com.gemstone.gemfire.cache.client package)
+ * <p>Global Regions, client Regions (see org.apache.geode.cache.client package)
  * and persistent Regions (see {@link DiskWriteAttributes}) do not
  * support transactions.
diff --git a/geode-core/src/main/java/org/apache/geode/cache/CacheWriterException.java b/geode-core/src/main/java/org/apache/geode/cache/CacheWriterException.java
index ca672ff..081cbc3 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/CacheWriterException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/CacheWriterException.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 /**
  * An exception thrown by a <code>CacheWriter</code> method. This exception
@@ -24,11 +24,11 @@ package com.gemstone.gemfire.cache;
  *
  *
  * @see CacheWriter
  * @see com.gemstone.gemfire.cache.Region#put(Object, Object)
  * @see com.gemstone.gemfire.cache.Region#destroy(Object)
  * @see com.gemstone.gemfire.cache.Region#create(Object, Object)
  * @see com.gemstone.gemfire.cache.Region#destroyRegion()
  * @see com.gemstone.gemfire.cache.Region#get(Object)
  * @since GemFire 3.0
  */
 public class CacheWriterException extends OperationAbortedException {

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/CacheXmlException.java
----------------------------------------------------------------------
@@ -24,11 +24,11 @@ package com.gemstone.gemfire.cache;
  *
  * @see CacheWriter
- * @see com.gemstone.gemfire.cache.Region#put(Object, Object)
- * @see com.gemstone.gemfire.cache.Region#destroy(Object)
- * @see com.gemstone.gemfire.cache.Region#create(Object, Object)
- * @see com.gemstone.gemfire.cache.Region#destroyRegion()
- * @see com.gemstone.gemfire.cache.Region#get(Object)
+ * @see org.apache.geode.cache.Region#put(Object, Object)
+ * @see org.apache.geode.cache.Region#destroy(Object)
+ * @see org.apache.geode.cache.Region#create(Object, Object)
+ * @see org.apache.geode.cache.Region#destroyRegion()
+ * @see org.apache.geode.cache.Region#get(Object)
  * @since GemFire 3.0
  */
diff --git a/geode-core/src/main/java/org/apache/geode/cache/ClientSession.java b/geode-core/src/main/java/org/apache/geode/cache/ClientSession.java
index 60673b8..321791e 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/ClientSession.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/ClientSession.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 /**
  * Class <code>ClientSession</code> represents a client connection on the
@@ -36,9 +36,9 @@ package com.gemstone.gemfire.cache;
  * </pre>
  * 
  * @since GemFire 6.0
- * @see com.gemstone.gemfire.cache.server.CacheServer#getClientSession(String)
+ * @see org.apache.geode.cache.server.CacheServer#getClientSession(String)
  *      getClientSession
- * @see com.gemstone.gemfire.cache.server.CacheServer#getClientSession(com.gemstone.gemfire.distributed.DistributedMember)
+ * @see org.apache.geode.cache.server.CacheServer#getClientSession(org.apache.geode.distributed.DistributedMember)
  *      getClientSession
  *
  */
@@ -52,7 +52,7 @@ public interface ClientSession {
    * @param keyOfInterest
    *          The key on which to register interest
    * @param policy
    *          The {@link com.gemstone.gemfire.cache.InterestResultPolicy}. Note:
    *          For the special token 'ALL_KEYS' and lists of keys, values are not
    *          pushed to the client.
    * @param isDurable
@@ -71,7 +71,7 @@ public interface ClientSession {
    * @param keyOfInterest
    *          The key to on which to register interest
    * @param policy
    *          The {@link com.gemstone.gemfire.cache.InterestResultPolicy}. Note:
    *          For the special token 'ALL_KEYS' and lists of keys, values are not
    *          pushed to the client.
    * @param isDurable

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/CommitConflictException.java
----------------------------------------------------------------------
@@ -52,7 +52,7 @@ public interface ClientSession {
    *          The key on which to register interest
    * @param policy
-   *          The {@link com.gemstone.gemfire.cache.InterestResultPolicy}. Note:
+   *          The {@link org.apache.geode.cache.InterestResultPolicy}. Note:
    *          For the special token 'ALL_KEYS' and lists of keys, values are not
    *          pushed to the client.
@@ -71,7 +71,7 @@ public interface ClientSession {
    *          The key to on which to register interest
    * @param policy
-   *          The {@link com.gemstone.gemfire.cache.InterestResultPolicy}. Note:
+   *          The {@link org.apache.geode.cache.InterestResultPolicy}. Note:
    *          For the special token 'ALL_KEYS' and lists of keys, values are not
    *          pushed to the client.
diff --git a/geode-core/src/main/java/org/apache/geode/cache/EntryNotFoundException.java b/geode-core/src/main/java/org/apache/geode/cache/EntryNotFoundException.java
index 8415f49..ddc666a 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/EntryNotFoundException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/EntryNotFoundException.java
@@ -15,16 +15,16 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 /** Thrown when an operation is invoked on <code>Region</code> for an entry that
  * doesn't exist in the <code>Region</code>. This exception is <i>not</i>
  * thrown by {@link com.gemstone.gemfire.cache.Region#get(Object)} or {@link Region#getEntry}.
  *
  *
  *
- * @see com.gemstone.gemfire.cache.Region#invalidate(Object)
- * @see com.gemstone.gemfire.cache.Region#destroy(Object)
+ * @see org.apache.geode.cache.Region#invalidate(Object)
+ * @see org.apache.geode.cache.Region#destroy(Object)
  * @see Region.Entry
  * @since GemFire 3.0
  */

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/EntryNotFoundInRegion.java
----------------------------------------------------------------------
@@ -15,16 +15,16 @@
 /** Thrown when an operation is invoked on <code>Region</code> for an entry that
  * doesn't exist in the <code>Region</code>. This exception is <i>not</i>
- * thrown by {@link com.gemstone.gemfire.cache.Region#get(Object)} or {@link Region#getEntry}.
+ * thrown by {@link org.apache.geode.cache.Region#get(Object)} or {@link Region#getEntry}.
  *
  *
diff --git a/geode-core/src/main/java/org/apache/geode/cache/EvictionAction.java b/geode-core/src/main/java/org/apache/geode/cache/EvictionAction.java
index 8bc1aaf..d9812f7 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/EvictionAction.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/EvictionAction.java
@@ -14,14 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 import javax.print.attribute.EnumSyntax;
 /**
  * The action that an {@link com.gemstone.gemfire.cache.EvictionAlgorithm} takes.
  * @since GemFire 5.0
- * @see com.gemstone.gemfire.cache.EvictionAlgorithm
- * @see com.gemstone.gemfire.internal.cache.EvictionAttributesImpl
+ * @see org.apache.geode.cache.EvictionAlgorithm
+ * @see org.apache.geode.internal.cache.EvictionAttributesImpl
  */
 public final class EvictionAction extends EnumSyntax
 {
@@ -30,7 +30,7 @@ public final class EvictionAction extends EnumSyntax
    */
   public static final EvictionAction NONE = new EvictionAction(0);
   
-  /** Perform a {@link com.gemstone.gemfire.cache.Region#localDestroy(Object)
+  /** Perform a {@link org.apache.geode.cache.Region#localDestroy(Object)
    * localDestory} on the least recently used region entry. */
   public static final EvictionAction LOCAL_DESTROY = new EvictionAction(1);
 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/EvictionAlgorithm.java
----------------------------------------------------------------------
@@ -14,14 +14,14 @@
 import javax.print.attribute.EnumSyntax;
 /**
- * The action that an {@link com.gemstone.gemfire.cache.EvictionAlgorithm} takes.
+ * The action that an {@link org.apache.geode.cache.EvictionAlgorithm} takes.
  * @since GemFire 5.0
diff --git a/geode-core/src/main/java/org/apache/geode/cache/EvictionAttributes.java b/geode-core/src/main/java/org/apache/geode/cache/EvictionAttributes.java
index 5f086ca..bd65fd8 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/EvictionAttributes.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/EvictionAttributes.java
@@ -15,21 +15,21 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
-import com.gemstone.gemfire.DataSerializable;
-import com.gemstone.gemfire.cache.control.ResourceManager;
-import com.gemstone.gemfire.cache.util.ObjectSizer;
-import com.gemstone.gemfire.internal.cache.EvictionAttributesImpl;
+import org.apache.geode.DataSerializable;
+import org.apache.geode.cache.control.ResourceManager;
+import org.apache.geode.cache.util.ObjectSizer;
+import org.apache.geode.internal.cache.EvictionAttributesImpl;
 
 /**
  * <p>Attributes that describe how a <code>Region</code>'s size is managed through an eviction controller. Eviction
  * controllers are defined by an {@link com.gemstone.gemfire.cache.EvictionAlgorithm} and a {@link
  * com.gemstone.gemfire.cache.EvictionAction}. Once a <code>Region</code> is created with an eviction controller, it can
  * not be removed, however it can be changed through an {@link com.gemstone.gemfire.cache.EvictionAttributesMutator}.
  *
- * @see com.gemstone.gemfire.cache.AttributesFactory#setEvictionAttributes(EvictionAttributes)
- * @see com.gemstone.gemfire.cache.AttributesMutator
+ * @see org.apache.geode.cache.AttributesFactory#setEvictionAttributes(EvictionAttributes)
+ * @see org.apache.geode.cache.AttributesMutator
  * @since GemFire 5.0
  */
 @SuppressWarnings("serial")

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/EvictionAttributesMutator.java
----------------------------------------------------------------------
@@ -15,21 +15,21 @@
 /**
  * <p>Attributes that describe how a <code>Region</code>'s size is managed through an eviction controller. Eviction
- * controllers are defined by an {@link com.gemstone.gemfire.cache.EvictionAlgorithm} and a {@link
- * com.gemstone.gemfire.cache.EvictionAction}. Once a <code>Region</code> is created with an eviction controller, it can
- * not be removed, however it can be changed through an {@link com.gemstone.gemfire.cache.EvictionAttributesMutator}.
+ * controllers are defined by an {@link org.apache.geode.cache.EvictionAlgorithm} and a {@link
+ * org.apache.geode.cache.EvictionAction}. Once a <code>Region</code> is created with an eviction controller, it can
+ * not be removed, however it can be changed through an {@link org.apache.geode.cache.EvictionAttributesMutator}.
  *
diff --git a/geode-core/src/main/java/org/apache/geode/cache/EvictionAttributesMutator.java b/geode-core/src/main/java/org/apache/geode/cache/EvictionAttributesMutator.java
index 9f4af59..672ddd4 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/EvictionAttributesMutator.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/EvictionAttributesMutator.java
@@ -14,14 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
-import com.gemstone.gemfire.internal.cache.EvictionAttributesImpl;
+import org.apache.geode.internal.cache.EvictionAttributesImpl;
 
 /**
  * The EvictionAttributesMutator allows changes to be made to a 
  * {@link com.gemstone.gemfire.cache.EvictionAttributes}. It is returned
  * by {@link com.gemstone.gemfire.cache.AttributesMutator#getEvictionAttributesMutator()}
  * @since GemFire 5.0
  */
 public interface EvictionAttributesMutator

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/ExpirationAction.java
----------------------------------------------------------------------
@@ -14,14 +14,14 @@
 /**
  * The EvictionAttributesMutator allows changes to be made to a 
- * {@link com.gemstone.gemfire.cache.EvictionAttributes}. It is returned
- * by {@link com.gemstone.gemfire.cache.AttributesMutator#getEvictionAttributesMutator()}
+ * {@link org.apache.geode.cache.EvictionAttributes}. It is returned
+ * by {@link org.apache.geode.cache.AttributesMutator#getEvictionAttributesMutator()}
  * @since GemFire 5.0
  */
diff --git a/geode-core/src/main/java/org/apache/geode/cache/FixedPartitionResolver.java b/geode-core/src/main/java/org/apache/geode/cache/FixedPartitionResolver.java
index db77807..23fddd8 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/FixedPartitionResolver.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/FixedPartitionResolver.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 import java.util.Set;
 
@@ -26,7 +26,7 @@ import java.util.Set;
  * which member the data is being managed. Say, for example, you want to
  * partition all Trades according to quarters. You can implement
  * FixedPartitionResolver to get the name of the quarter based on the date given
  * as part of {@link com.gemstone.gemfire.cache.EntryOperation}.
  * </p>
  * 
  * public class QuarterPartitionResolver implements FixedPartitionResolver{<br>

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/GatewayConfigurationException.java
----------------------------------------------------------------------
@@ -26,7 +26,7 @@ import java.util.Set;
  * partition all Trades according to quarters. You can implement
  * FixedPartitionResolver to get the name of the quarter based on the date given
- * as part of {@link com.gemstone.gemfire.cache.EntryOperation}.
+ * as part of {@link org.apache.geode.cache.EntryOperation}.
  * </p>
  * 
diff --git a/geode-core/src/main/java/org/apache/geode/cache/InterestRegistrationListener.java b/geode-core/src/main/java/org/apache/geode/cache/InterestRegistrationListener.java
index 370d47b..195f130 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/InterestRegistrationListener.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/InterestRegistrationListener.java
@@ -15,14 +15,14 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 /**
  * Interface <code>InterestRegisterationListener</code> provides the ability for
  * applications to be notified of interest registration and unregistration
  * events. Instances must be implemented by applications and registered in
  * <code>CacheServer</code> VMs using the
- * {@link com.gemstone.gemfire.cache.server.CacheServer#registerInterestRegistrationListener
+ * {@link org.apache.geode.cache.server.CacheServer#registerInterestRegistrationListener
  * registerInterestRegistrationListener} API. The methods on an
  * <code>InterestRegisterationListener</code> are invoked synchronously with the
  * interest event in any <code>CacheServer</code> VM hosting the requesting
@@ -31,8 +31,8 @@ package com.gemstone.gemfire.cache;
  * <p>Shown below is an example implementation.
  *
  * <pre>
- *import com.gemstone.gemfire.cache.InterestRegistrationEvent;
- *import com.gemstone.gemfire.cache.InterestRegistrationListener;
+ *import org.apache.geode.cache.InterestRegistrationEvent;
+ *import org.apache.geode.cache.InterestRegistrationListener;
  *
  *public class TestInterestRegistrationListener implements InterestRegistrationListener {
  *
@@ -62,8 +62,8 @@ package com.gemstone.gemfire.cache;
  *
  * @since GemFire 6.0
  * 
  * @see com.gemstone.gemfire.cache.server.CacheServer#registerInterestRegistrationListener registerInterestRegistrationListener
  * @see com.gemstone.gemfire.cache.server.CacheServer#unregisterInterestRegistrationListener unregisterInterestRegistrationListener
  */
 public interface InterestRegistrationListener extends CacheCallback {
 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/InterestResultPolicy.java
----------------------------------------------------------------------
@@ -62,8 +62,8 @@ package com.gemstone.gemfire.cache;
  * @since GemFire 6.0
  * 
- * @see com.gemstone.gemfire.cache.server.CacheServer#registerInterestRegistrationListener registerInterestRegistrationListener
- * @see com.gemstone.gemfire.cache.server.CacheServer#unregisterInterestRegistrationListener unregisterInterestRegistrationListener
+ * @see org.apache.geode.cache.server.CacheServer#registerInterestRegistrationListener registerInterestRegistrationListener
+ * @see org.apache.geode.cache.server.CacheServer#unregisterInterestRegistrationListener unregisterInterestRegistrationListener
  */
 public interface InterestRegistrationListener extends CacheCallback {
diff --git a/geode-core/src/main/java/org/apache/geode/cache/MembershipAttributes.java b/geode-core/src/main/java/org/apache/geode/cache/MembershipAttributes.java
index 5a1c451..cf87e90 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/MembershipAttributes.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/MembershipAttributes.java
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
-import com.gemstone.gemfire.DataSerializable;
-import com.gemstone.gemfire.DataSerializer;
-import com.gemstone.gemfire.distributed.internal.membership.InternalRole;
-import com.gemstone.gemfire.distributed.Role;
-import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
+import org.apache.geode.DataSerializable;
+import org.apache.geode.DataSerializer;
+import org.apache.geode.distributed.internal.membership.InternalRole;
+import org.apache.geode.distributed.Role;
+import org.apache.geode.internal.i18n.LocalizedStrings;
 
 import java.io.*;
 import java.util.*;
@@ -120,7 +120,7 @@ public class MembershipAttributes implements DataSerializable, Externalizable {
   }
   
   /**
    * Returns the set of {@linkplain com.gemstone.gemfire.distributed.Role 
    * Role}s that are required for the reliability of this region.
    */
   public Set<Role> getRequiredRoles() {

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/MirrorType.java
----------------------------------------------------------------------
@@ -120,7 +120,7 @@ public class MembershipAttributes implements DataSerializable, Externalizable {
   
   /**
-   * Returns the set of {@linkplain com.gemstone.gemfire.distributed.Role 
+   * Returns the set of {@linkplain org.apache.geode.distributed.Role 
    * Role}s that are required for the reliability of this region.
    */
diff --git a/geode-core/src/main/java/org/apache/geode/cache/PartitionAttributes.java b/geode-core/src/main/java/org/apache/geode/cache/PartitionAttributes.java
index e2f5479..90f7b6f 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/PartitionAttributes.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/PartitionAttributes.java
@@ -15,27 +15,27 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 import java.util.List;
 import java.util.Properties;
 
-import com.gemstone.gemfire.cache.PartitionResolver;
-import com.gemstone.gemfire.cache.partition.PartitionListener;
+import org.apache.geode.cache.PartitionResolver;
+import org.apache.geode.cache.partition.PartitionListener;
 
 /**
  * 
  * Attributes that define the partitioned character of a Partitioned Region.  
  * This interface allows for the discovery of Partitioned Region attributes using 
  * {@link com.gemstone.gemfire.cache.RegionAttributes#getPartitionAttributes()} as well
  * as the configuration of a Partitioned Region using {@link com.gemstone.gemfire.cache.AttributesFactory#setPartitionAttributes(PartitionAttributes)}.
  * 
- * PartitionAttributes are created using the {@link com.gemstone.gemfire.cache.PartitionAttributesFactory}
+ * PartitionAttributes are created using the {@link org.apache.geode.cache.PartitionAttributesFactory}
  * 
  * The default PartitionAttributes can be determined using {@link com.gemstone.gemfire.cache.PartitionAttributesFactory#create()} with out
  * calling any of its mutator methods e.g.  {@link com.gemstone.gemfire.cache.PartitionAttributesFactory#setLocalMaxMemory(int)}
  *
  * Also see {@link com.gemstone.gemfire.cache.DataPolicy#PARTITION}.
  * 
  * @since GemFire 5.0
  * 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/PartitionAttributesFactory.java
----------------------------------------------------------------------
@@ -15,27 +15,27 @@
  * Attributes that define the partitioned character of a Partitioned Region.  
  * This interface allows for the discovery of Partitioned Region attributes using 
- * {@link com.gemstone.gemfire.cache.RegionAttributes#getPartitionAttributes()} as well
- * as the configuration of a Partitioned Region using {@link com.gemstone.gemfire.cache.AttributesFactory#setPartitionAttributes(PartitionAttributes)}.
+ * {@link org.apache.geode.cache.RegionAttributes#getPartitionAttributes()} as well
+ * as the configuration of a Partitioned Region using {@link org.apache.geode.cache.AttributesFactory#setPartitionAttributes(PartitionAttributes)}.
  * 
@@ -15,27 +15,27 @@
  * 
- * The default PartitionAttributes can be determined using {@link com.gemstone.gemfire.cache.PartitionAttributesFactory#create()} with out
- * calling any of its mutator methods e.g.  {@link com.gemstone.gemfire.cache.PartitionAttributesFactory#setLocalMaxMemory(int)}
+ * The default PartitionAttributes can be determined using {@link org.apache.geode.cache.PartitionAttributesFactory#create()} with out
+ * calling any of its mutator methods e.g.  {@link org.apache.geode.cache.PartitionAttributesFactory#setLocalMaxMemory(int)}
  *
@@ -15,27 +15,27 @@
  *
- * Also see {@link com.gemstone.gemfire.cache.DataPolicy#PARTITION}.
+ * Also see {@link org.apache.geode.cache.DataPolicy#PARTITION}.
  * 
  * @since GemFire 5.0
diff --git a/geode-core/src/main/java/org/apache/geode/cache/PartitionAttributesFactory.java b/geode-core/src/main/java/org/apache/geode/cache/PartitionAttributesFactory.java
index 7489b89..0fdc245 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/PartitionAttributesFactory.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/PartitionAttributesFactory.java
@@ -15,13 +15,13 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 import java.util.Properties;
 
-import com.gemstone.gemfire.cache.partition.PartitionListener;
-import com.gemstone.gemfire.internal.cache.PartitionAttributesImpl;
-import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
+import org.apache.geode.cache.partition.PartitionListener;
+import org.apache.geode.internal.cache.PartitionAttributesImpl;
+import org.apache.geode.internal.i18n.LocalizedStrings;
 
 /**
  * <p>
@@ -50,10 +50,10 @@ import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
  * {@link PartitionAttributes} can also be defined in a declarative fashion using a
  * <a href="package-summary.html#declarative">cache.xml</a> file. Here is an
  * example of how to configure a Partitioned Region named "pRoot" whose 
  * {@link com.gemstone.gemfire.cache.Scope} is Distributed Ack, which maintains
  * a {@link #setRedundantCopies(int) redundant copy} of any given 
  * {@link com.gemstone.gemfire.cache.Region.Entry}, configures a 
  * {@link com.gemstone.gemfire.cache.CacheLoader} implementation, and sets 
  * {@link #setGlobalProperties(Properties) global properties} as well as 
  * {@link #setLocalMaxMemory(int) local max memory to use}.
  * 
@@ -66,8 +66,8 @@ import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
  * </pre>
  * </p>
  * 
- * @see com.gemstone.gemfire.cache.PartitionAttributes
- * @see com.gemstone.gemfire.cache.AttributesFactory#setPartitionAttributes(PartitionAttributes)
+ * @see org.apache.geode.cache.PartitionAttributes
+ * @see org.apache.geode.cache.AttributesFactory#setPartitionAttributes(PartitionAttributes)
  * @since GemFire 5.0
  */
 public class PartitionAttributesFactory<K,V>
@@ -223,7 +223,7 @@ public class PartitionAttributesFactory<K,V>
    * <em>This setting must be the same in all processes using the Region.</em>
    * <p>
    * A bucket is the smallest unit of data management in a partitioned region.
    * {@link com.gemstone.gemfire.cache.Region.Entry Entries} are stored in
    * buckets and buckets may move from one VM to another. Buckets may also have
    * copies, depending on {@link #setRedundantCopies(int) redundancy} to provide
    * high availability in the face of VM failure.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/PartitionResolver.java
----------------------------------------------------------------------
@@ -50,10 +50,10 @@ import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
  * <a href="package-summary.html#declarative">cache.xml</a> file. Here is an
  * example of how to configure a Partitioned Region named "pRoot" whose 
- * {@link com.gemstone.gemfire.cache.Scope} is Distributed Ack, which maintains
+ * {@link org.apache.geode.cache.Scope} is Distributed Ack, which maintains
  * a {@link #setRedundantCopies(int) redundant copy} of any given 
@@ -50,10 +50,10 @@ import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
  * a {@link #setRedundantCopies(int) redundant copy} of any given 
- * {@link com.gemstone.gemfire.cache.Region.Entry}, configures a 
- * {@link com.gemstone.gemfire.cache.CacheLoader} implementation, and sets 
+ * {@link org.apache.geode.cache.Region.Entry}, configures a 
+ * {@link org.apache.geode.cache.CacheLoader} implementation, and sets 
  * {@link #setGlobalProperties(Properties) global properties} as well as 
  * {@link #setLocalMaxMemory(int) local max memory to use}.
@@ -223,7 +223,7 @@ public class PartitionAttributesFactory<K,V>
    * <p>
    * A bucket is the smallest unit of data management in a partitioned region.
-   * {@link com.gemstone.gemfire.cache.Region.Entry Entries} are stored in
+   * {@link org.apache.geode.cache.Region.Entry Entries} are stored in
    * buckets and buckets may move from one VM to another. Buckets may also have
    * copies, depending on {@link #setRedundantCopies(int) redundancy} to provide